@@ -92,21 +92,21 @@ namespace Tangerine
             public uint      len;
         }
 
-        [DllImport ("libtangglue")]
+        [DllImport ("tangglue")]
         static extern int inotify_glue_init ();
 
-        [DllImport ("libtangglue")]
+        [DllImport ("tangglue")]
         static extern int inotify_glue_watch (int fd, string filename, EventType mask);
 
-        [DllImport ("libtangglue")]
+        [DllImport ("tangglue")]
         static extern int inotify_glue_ignore (int fd, int wd);
 
-        [DllImport ("libtangglue")]
+        [DllImport ("tangglue")]
         static extern unsafe void inotify_snarf_events (int fd,
                                                         out int nr,
                                                         out IntPtr buffer);
 
-        [DllImport ("libtangglue")]
+        [DllImport ("tangglue")]
         static extern void inotify_snarf_cancel ();
 
         /////////////////////////////////////////////////////////////////////////////////////
